@@ -9,6 +9,7 @@ import logging
 import math
 import os
 import sys
+import warnings
 # third-party modules
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -94,6 +95,9 @@ if __name__ == "__main__":
     formatter = logging.Formatter(fmt=logFmt, datefmt=logDateFmt )
     logging.basicConfig(format=logFmt, datefmt=logDateFmt)
 
+    # treat numpy deprecations as errors
+    warnings.filterwarnings('error', category=np.VisibleDeprecationWarning)
+
     ap = argparse.ArgumentParser( description=__doc__, fromfile_prefix_chars='@', formatter_class=argparse.ArgumentDefaultsHelpFormatter )
     ap.add_argument( '--dataDirPath', required=True, help='the path to to directory for input and output data' )
     args = ap.parse_args()
@@ -132,15 +136,42 @@ if __name__ == "__main__":
     completedJobs = demuxResults(jlogFilePath)
 
     mappedFrameNumLocation = []
+    mappedFrameNumLocationUnitedStates = []
+    mappedFrameNumLocationRussia = []
+    mappedFrameNumLocationOther = []
+    
     for i in range(0,len(completedJobs)):
         for j in range(0,len(launchedInstances)):
             if launchedInstances[j]["instanceId"] == completedJobs[i][1]:
                 mappedFrameNumLocation.append([completedJobs[i][0],
-                                            launchedInstances[j]["device-location"]["latitude"],
-                                            launchedInstances[j]["device-location"]["longitude"],
-                                            launchedInstances[j]["device-location"]["display-name"],
-                                            launchedInstances[j]["device-location"]["country"]
-                                            ])
+                                           launchedInstances[j]["device-location"]["latitude"],
+                                           launchedInstances[j]["device-location"]["longitude"],
+                                           launchedInstances[j]["device-location"]["display-name"],
+                                           launchedInstances[j]["device-location"]["country"]
+                                           ])
+                if launchedInstances[j]["device-location"]["country"] == "United States":
+                    mappedFrameNumLocationUnitedStates.append([completedJobs[i][0],
+                                               launchedInstances[j]["device-location"]["latitude"],
+                                               launchedInstances[j]["device-location"]["longitude"],
+                                               launchedInstances[j]["device-location"]["display-name"],
+                                               launchedInstances[j]["device-location"]["country"]
+                                               ])
+                elif launchedInstances[j]["device-location"]["country"] == "Russia":
+                    mappedFrameNumLocationRussia.append([completedJobs[i][0],
+                                               launchedInstances[j]["device-location"]["latitude"],
+                                               launchedInstances[j]["device-location"]["longitude"],
+                                               launchedInstances[j]["device-location"]["display-name"],
+                                               launchedInstances[j]["device-location"]["country"]
+                                               ])
+                else:
+                    mappedFrameNumLocationOther.append([completedJobs[i][0],
+                                               launchedInstances[j]["device-location"]["latitude"],
+                                               launchedInstances[j]["device-location"]["longitude"],
+                                               launchedInstances[j]["device-location"]["display-name"],
+                                               launchedInstances[j]["device-location"]["country"]
+                                               ])
+                
+
 
     print("\nLocations:")
     for i in range(0,len(mappedFrameNumLocation)):
@@ -185,62 +216,41 @@ if __name__ == "__main__":
                 if frameNum == mappedFrameNumLocation[j][0]:
                     jIndex = j
             responseData.append([frameNum,minStartTimeForDevice,startTimes,elapsedTimes,mappedFrameNumLocation[jIndex]])
-    globalMinStartTime = min(getColumn(responseData,1))
-
-    if False:
-        for i in range(0,len(responseData)):
-            print("%d  %.3f  %s" %(responseData[i][0],responseData[i][1],responseData[i][4]))
-        print(globalMinStartTime)
+    if not responseData:
+        sys.exit( 'no plottable data was found' )
 
+    # first, time-shift all startTimes by subtracting the minStartTime for each device
+    # and compute the maxStartTime (i.e. test duration) for each device
     relativeResponseData = []
     for i in range(0,len(responseData)):
         relativeStartTimes = []
         for ii in range(0,len(responseData[i][2])):
-            difference = responseData[i][2][ii]-globalMinStartTime
+            # difference = responseData[i][2][ii]-globalMinStartTime
             # if i==2 and ii<3700 and difference > 500:
             #     print("i = %d   ii = %d   difference = %f    data = %f" % (i,ii,difference,responseData[i][2][ii] ))
-            relativeStartTimes.append(responseData[i][2][ii]-globalMinStartTime) 
-        relativeResponseData.append([responseData[i][0],relativeStartTimes,responseData[i][3],responseData[i][4]])
+            # relativeStartTimes.append(responseData[i][2][ii]-globalMinStartTime)
+            relativeStartTimes.append(responseData[i][2][ii]-responseData[i][1])
+        maxStartTime = max(relativeStartTimes)
+        relativeResponseData.append([responseData[i][0],relativeStartTimes,responseData[i][3],responseData[i][4],maxStartTime])
 
-    # get first start times
-    firstStartTimes = []
-    for i in range(0,len(relativeResponseData)):
-        firstStartTimes.append(relativeResponseData[i][1][0])
+    # compute median maxStartTime
+    medianMaxStartTime = np.median(getColumn(relativeResponseData,4))
+    print("medianMaxStartTime = %f" % medianMaxStartTime)
 
-    minFirstStartTimes = min(firstStartTimes)
-    for i in range(0,len(relativeResponseData)):
-        if relativeResponseData[i][1][0] == minFirstStartTimes:
-            iIndex = i
-
-    sortedFirstStartTimes = np.sort(firstStartTimes)    
-    print("First Start Times = %s" % sortedFirstStartTimes)
-
-    if len(sortedFirstStartTimes)>1 and sortedFirstStartTimes[1] > 30:
-        # exclude first early record, it's an outlier
-        relativeResponseData2 = []
-        for i in range(0,len(relativeResponseData)):
-            if i != iIndex: 
-                relativeStartTimes2 = [(ii-sortedFirstStartTimes[1]) for ii in relativeResponseData[i][1]]
-                relativeResponseData2.append([relativeResponseData[i][0],relativeStartTimes2,relativeResponseData[i][2],relativeResponseData[i][3]])
-    else:
-        relativeResponseData2 = relativeResponseData    
-
-
-    # remove device records which started too late
-    # print(relativeResponseData[0])    
+    # remove device records which ran too long
+    # print(relativeResponseData[0])
     culledRelativeResponseData = []
     cullResponseData = True
-    startDelayThreshold = 30  # in seconds
-    maxAllowedDuration = 600  # in seconds
-    for i in range(0,len(relativeResponseData2)):
+    excessDurationThreshold = 30  # in seconds
+    for i in range(0,len(relativeResponseData)):
         if cullResponseData:
-            if relativeResponseData2[i][1][0] < startDelayThreshold and max(relativeResponseData2[i][1])<maxAllowedDuration:
+            # print("i = %d   min, max = %f  %f" % (i,min(relativeResponseData[i][1]),max(relativeResponseData[i][1])))
+            if relativeResponseData[i][4]<(medianMaxStartTime+excessDurationThreshold):
                 # print("min, max = %f  %f" % (min(relativeResponseData2[i][1]),max(relativeResponseData2[i][1])))
-                culledRelativeResponseData.append(relativeResponseData2[i])
+                culledRelativeResponseData.append(relativeResponseData[i])
         else:
-            culledRelativeResponseData.append(relativeResponseData2[i])
-            
-            
+            culledRelativeResponseData.append(relativeResponseData[i])
+
     print("Number of devices = %d" % len(relativeResponseData))
     print("Culled Number of devices = %d" %len(culledRelativeResponseData))
     culledLocations = getColumn(getColumn(culledRelativeResponseData,3),3)
@@ -372,7 +382,10 @@ if __name__ == "__main__":
             CountrySphericalData.append([countryString,coordinateSphericalList])
 
     figSize1 = (19.2, 10.8)
-    fontFactor = .5
+    fontFactor = 0.75
+    mpl.rcParams.update({'font.size': 22})
+    mpl.rcParams['axes.linewidth'] = 2 #set the value globally
+    markerSizeValue = 10
 
     # plot world map
     fig = plt.figure(3, figsize=figSize1)
@@ -383,24 +396,26 @@ if __name__ == "__main__":
     # ax.set_aspect('equal')
     # for i in range(0,20) :
     colorValue = 0.85
-    for i in range(0,len(CountryData)) :
-        if len(np.shape(CountryData[i][1]))==2 :
-            # plt.plot(np.transpose(CountryData[i][1])[0],np.transpose(CountryData[i][1])[1])
-            ax.add_artist(plt.Polygon(CountryData[i][1],edgecolor='None', facecolor=(colorValue,colorValue,colorValue),aa=True))           
+    edgeColor = None  # (colorValue*.9, colorValue*.9, colorValue*.9)
 
-        else :      
-            # print("%s       %s" % (CountryData[i][0],np.shape(CountryData[i][1])[0]))
-            for j in range(0,np.shape(CountryData[i][1])[0]) :
-                # print("%s" % CountryData[i][1][j])
-                # plt.plot(np.transpose(CountryData[i][1][j])[0],np.transpose(CountryData[i][1][j])[1])        
-                ax.add_artist(plt.Polygon(CountryData[i][1][j],edgecolor='None', facecolor=(colorValue,colorValue,colorValue),aa=True))           
-    plt.plot(getColumn(mappedFrameNumLocation,2),getColumn(mappedFrameNumLocation,1),linestyle='', color=(0.0, 0.5, 1.0),marker='o',markersize=15)
+    for i in range(0,len(CountryData)) :
+        if isinstance( CountryData[i][1], np.ndarray ):
+            ax.add_artist(plt.Polygon(CountryData[i][1],edgecolor=edgeColor,
+                facecolor=(colorValue,colorValue,colorValue),aa=True))
+        else :
+            for j in range(0,len(CountryData[i][1])) :
+                ax.add_artist(plt.Polygon(CountryData[i][1][j],edgecolor=edgeColor,
+                    facecolor=(colorValue,colorValue,colorValue),aa=True))
+
+    plt.plot(getColumn(mappedFrameNumLocationUnitedStates,2),getColumn(mappedFrameNumLocationUnitedStates,1),linestyle='', color=(0.0, 0.5, 1.0),marker='o',markersize=markerSizeValue)
+    plt.plot(getColumn(mappedFrameNumLocationRussia,2),getColumn(mappedFrameNumLocationRussia,1),linestyle='', color=(1.0, 0.0, 0.0),marker='o',markersize=markerSizeValue)
+    plt.plot(getColumn(mappedFrameNumLocationOther,2),getColumn(mappedFrameNumLocationOther,1),linestyle='', color=(0.0, 0.9, 0.0),marker='o',markersize=markerSizeValue)
     plt.xlim([-180,180])
     plt.ylim([-60,90])
     #plt.show()
-    plt.savefig( outputDir+'/worldMap.png' )
+    plt.savefig( outputDir+'/worldMap.png', bbox_inches='tight')
 
-    plotMarkerSize = 4
+    plotMarkerSize = 3
     plt.figure(10, figsize=figSize1)
     plt.plot(startRelTimesAndMSPRsUnitedStates[0],startRelTimesAndMSPRsUnitedStates[1], linestyle='', color=(0.0, 0.6, 1.0),marker='o',markersize=plotMarkerSize)
     plt.plot(startRelTimesAndMSPRsRussia[0],startRelTimesAndMSPRsRussia[1], linestyle='', color=(1.0, 0.0, 0.0),marker='o',markersize=plotMarkerSize)
