@@ -4,8 +4,12 @@ import glob
 import json
 import os
 import re
+import sys
 import subprocess
 
+import pytest
+
+
 def check_batchRunner_results( jlogFilePath ):
     with open( jlogFilePath, 'r') as inFile:
         for line in inFile:
@@ -13,7 +17,7 @@ def check_batchRunner_results( jlogFilePath ):
         lastLine = line
     #print( 'the last line was', lastLine )
     decoded = json.loads( lastLine )
-    print( 'decoded last line:', decoded )
+    #print( 'decoded last line:', decoded )
 
     assert decoded.get( 'type' ) == 'operation', 'not operation'
     assert 'args' in decoded, 'no args'
@@ -27,6 +31,8 @@ def check_batchRunner_example( exampleName, frameFilePattern=None ):
     binPath = './' + exampleName + '.py'
     proc = subprocess.run( [binPath], stderr=subprocess.PIPE )
     rc = proc.returncode
+    if rc:
+        print( proc.stderr.decode('utf-8'), file=sys.stderr )
     assert rc==0, exampleName+' returned non-zero rc'
     stderr = proc.stderr.decode('utf-8')
     assert 'args.outDataDir' in stderr, 'no args.outDataDir in stderr'
@@ -45,15 +51,35 @@ def check_batchRunner_example( exampleName, frameFilePattern=None ):
 def test_authToken():
     assert os.getenv('NCS_AUTH_TOKEN'), 'env var NCS_AUTH_TOKEN not found'
 
+def test_imports():
+    import ncscli
+    import ncscli.batchRunner
+
+def test_path():
+    rc = subprocess.call( 'hash ncs.py', shell=True )
+    assert rc==0, 'ncs.py was not found in the PATH'
+
 def test_runBatchBinary():
+    # check if the built ARM executable already exists
     if not os.path.isfile('helloFrame_aarch64'):
+        # check if the C compiler is available
+        rc = subprocess.call( 'hash aarch64-linux-gnu-gcc', shell=True )
+        if rc != 0:
+            pytest.xfail( 'C compiler not found (for building helloFrame_aarch64)' )
+        # build the ARM executable
         rc = subprocess.call( ['aarch64-linux-gnu-gcc', '-o', 'helloFrame_aarch64', 'helloFrame.c'] )
         assert rc==0, 'could not build helloFrameGo_aarch64'
 
     check_batchRunner_example( 'runBatchBinary', 'frame_*.out' )
 
 def test_runBatchBinaryGo():
+    # check if the built ARM executable already exists
     if not os.path.isfile('helloFrameGo_aarch64'):
+        # check if the go compiler is available
+        rc = subprocess.call( 'hash go', shell=True )
+        if rc != 0:
+            pytest.xfail( '"go" compiler not found (for building helloFrameGo_aarch64)' )
+        # build the ARM executable
         rc = subprocess.call( 'GOARCH=arm64 go build -o helloFrameGo_aarch64 helloFrameGo.go', shell=True )
         assert rc==0, 'could not build helloFrame_aarch64'
 
@@ -62,9 +88,28 @@ def test_runBatchBinaryGo():
 def test_runBatchBlender():
     check_batchRunner_example( 'runBatchBlender', 'rendered_frame_*.png' )
 
+def test_runBatchGatling():
+    check_batchRunner_example( 'runBatchGatling', 'gatlingResults_*' )
+
 def test_runBatchJMeter():
     check_batchRunner_example( 'runBatchJMeter', 'TestPlan_results_*.csv' )
 
+def test_runBatchK6():
+    # check if the built ARM executable already exists
+    if not os.path.isfile('k6Worker/k6'):
+        # check if the go compiler is available
+        rc = subprocess.call( 'hash go', shell=True )
+        if rc != 0:
+            pytest.xfail( '"go" compiler not found (for building k6Worker/k6)' )
+        # build the ARM executable
+        rc = subprocess.call( 'GOARCH=arm64 GOPATH=$PWD/go go get github.com/loadimpact/k6', shell=True )
+        assert rc==0, 'could not build k6 for Arm64'
+        # copy ARM executable to k6worker dir
+        rc = subprocess.call( 'cp -p go/bin/linux_arm64/k6 k6Worker', shell=True )
+        assert rc==0, 'could not copy ARM executable to k6worker dir'
+
+    check_batchRunner_example( 'runBatchK6', 'worker_*.csv' )
+
 def test_runBatchLoadtest():
     check_batchRunner_example( 'runBatchLoadtest', 'worker_*.csv' )
 
